@@ -57,10 +57,9 @@
       (setq rev2buf (current-buffer)
 	    file2 (buffer-file-name)))
     (setq startup-hooks
-	  (cons (` (lambda ()
-		     (delete-file (, file1))
-		     (or (, (string= rev2 "")) (delete-file (, file2)))
-		     ))
+	  (cons `(lambda ()
+		   (delete-file ,file1)
+		   (or ,(string= rev2 "") (delete-file ,file2)))
 		startup-hooks))
     (ediff-buffers
      rev1buf rev2buf
@@ -159,19 +158,20 @@
       (setq buf2 (current-buffer)))
     (if ancestor-rev
 	(save-excursion
-	  (or (string= ancestor-rev "")
-	      (vc-version-other-window ancestor-rev))
+	  (if (string= ancestor-rev "")
+	      (setq ancestor-rev (vc-workfile-version buffer-file-name)))
+	  (vc-version-other-window ancestor-rev)
 	  (setq ancestor-buf (current-buffer))))
     (setq startup-hooks 
 	  (cons 
-	   (` (lambda () 
-		(delete-file (, (buffer-file-name buf1)))
-		(or (, (string= rev2 ""))
-		    (delete-file (, (buffer-file-name buf2))))
-		(or (, (string= ancestor-rev ""))
-		    (, (not ancestor-rev))
-		    (delete-file (, (buffer-file-name ancestor-buf))))
-		))
+	   `(lambda () 
+	      (delete-file ,(buffer-file-name buf1))
+	      (or ,(string= rev2 "")
+		  (delete-file ,(buffer-file-name buf2)))
+	      (or ,(string= ancestor-rev "")
+		  ,(not ancestor-rev)
+		  (delete-file ,(buffer-file-name ancestor-buf)))
+	      )
 	   startup-hooks))
     (if ancestor-rev
 	(ediff-merge-buffers-with-ancestor
